============
 To-Do List
============

Many features that can be easily added to CairoSVG are listed in the different
folders of the ``test/fail`` directory.

1.0
===

- Handle character rotations
- Clean code and remove useless TODOs


Future
======

- Filters (fe*, filters* and mask*)
- Mixed relative/absolute shorthands for curves in paths
- Markers on shapes
- Clean text rendering (textdecoration*)
